Adding some flesh to the simple device manager.
diff --git a/net/api/src/main/java/org/onlab/onos/net/device/DeviceProviderService.java b/net/api/src/main/java/org/onlab/onos/net/device/DeviceProviderService.java
index 9d8eb6a..f304398 100644
--- a/net/api/src/main/java/org/onlab/onos/net/device/DeviceProviderService.java
+++ b/net/api/src/main/java/org/onlab/onos/net/device/DeviceProviderService.java
@@ -34,17 +34,17 @@
      * determine what has changed.
      * <p/>
      *
      * @param deviceId identity of the device
      * @param ports list of device ports
      */
-    void updatePorts(DeviceId deviceId, List<PortDescription> ports);
+    void updatePorts(DeviceId deviceId, List<PortDescription> portDescriptions);
 
     /**
      * Used to notify the core about port status change of a single port.
      *
-     * @param deviceId identity of the device
-     * @param port description of the port that changed
+     * @param deviceId        identity of the device
+     * @param portDescription description of the port that changed
      */
-    void portStatusChanged(DeviceId deviceId, PortDescription port);
+    void portStatusChanged(DeviceId deviceId, PortDescription portDescription);
 
 }
@@ -34,17 +34,17 @@
      * <p/>
      *
-     * @param deviceId identity of the device
-     * @param ports list of device ports
+     * @param deviceId         identity of the device
+     * @param portDescriptions list of device ports
      */